@@ -16,7 +16,7 @@ import (
 	"github.com/asipto/secsipidx/secsipid"
 )
 
-const secsipidxVersion = "1.2.0"
+const secsipidxVersion = "1.3.0"
 
 // CLIOptions - structure for command line options
 type CLIOptions struct {
@@ -56,6 +56,7 @@ type CLIOptions struct {
 	cainter     string
 	crlfile     string
 	certverify  int
+	verbosity   int
 }
 
 var cliops = CLIOptions{
@@ -95,6 +96,7 @@ var cliops = CLIOptions{
 	cainter:     "",
 	crlfile:     "",
 	certverify:  0,
+	verbosity:   0,
 }
 
 // initialize application components
@@ -123,12 +125,12 @@ func init() {
 	flag.StringVar(&cliops.payload, "payload", cliops.payload, "payload value in JSON format")
 	flag.StringVar(&cliops.fidentity, "fidentity", cliops.fidentity, "path to file with identity value")
 	flag.StringVar(&cliops.identity, "identity", cliops.identity, "identity value")
-	flag.StringVar(&cliops.alg, "alg", cliops.alg, "encryption algorithm (default: ES256)")
-	flag.StringVar(&cliops.ppt, "ppt", cliops.ppt, "used extension (default: shaken)")
-	flag.StringVar(&cliops.typ, "typ", cliops.typ, "token type (default: passport)")
+	flag.StringVar(&cliops.alg, "alg", cliops.alg, "encryption algorithm")
+	flag.StringVar(&cliops.ppt, "ppt", cliops.ppt, "used extension")
+	flag.StringVar(&cliops.typ, "typ", cliops.typ, "token type")
 	flag.StringVar(&cliops.x5u, "x5u", cliops.x5u, "value of the field with the location of the certificate used to sign the token (default: '')")
-	flag.StringVar(&cliops.attest, "attest", cliops.attest, "attestation level (default: 'C')")
-	flag.StringVar(&cliops.attest, "a", cliops.attest, "attestation level (default: 'C')")
+	flag.StringVar(&cliops.attest, "attest", cliops.attest, "attestation level")
+	flag.StringVar(&cliops.attest, "a", cliops.attest, "attestation level")
 	flag.StringVar(&cliops.desttn, "dest-tn", cliops.desttn, "destination (called) number (default: '')")
 	flag.StringVar(&cliops.desttn, "d", cliops.desttn, "destination (called) number (default: '')")
 	flag.StringVar(&cliops.origtn, "orig-tn", cliops.origtn, "origination (calling) number (default: '')")
@@ -137,22 +139,24 @@ func init() {
 	flag.StringVar(&cliops.origid, "orig-id", cliops.origid, "origination identifier (default: '')")
 	flag.BoolVar(&cliops.check, "check", cliops.check, "check validity of the signature")
 	flag.BoolVar(&cliops.check, "c", cliops.check, "check validity of the signature")
-	flag.BoolVar(&cliops.sign, "sign", cliops.sign, "sign the header and payload")
-	flag.BoolVar(&cliops.sign, "s", cliops.sign, "sign the header and payload")
-	flag.BoolVar(&cliops.signfull, "sign-full", cliops.sign, "sign the header and payload, with parameters")
+	flag.BoolVar(&cliops.sign, "sign", cliops.sign, "sign the header and payload given as full JSON documents")
+	flag.BoolVar(&cliops.sign, "s", cliops.sign, "sign the header and payload given as full JSON documents")
+	flag.BoolVar(&cliops.signfull, "sign-full", cliops.sign, "sign the header and payload build from the individual parameter values")
 	flag.BoolVar(&cliops.signfull, "S", cliops.sign, "sign the header and payload, with parameters")
-	flag.BoolVar(&cliops.jsonparse, "json-parse", cliops.jsonparse, "parse and re-serialize JSON header and payaload values")
+	flag.BoolVar(&cliops.jsonparse, "json-parse", cliops.jsonparse, "parse and re-serialize JSON header and payload values")
 	flag.IntVar(&cliops.expire, "expire", cliops.expire, "duration of token validity (in seconds)")
-	flag.IntVar(&cliops.timeout, "timeout", cliops.timeout, "http get timeout (in seconds, default: 3)")
+	flag.IntVar(&cliops.timeout, "timeout", cliops.timeout, "http get timeout (in seconds)")
 	flag.BoolVar(&cliops.ltest, "ltest", cliops.ltest, "run local basic test")
 	flag.BoolVar(&cliops.ltest, "l", cliops.ltest, "run local basic test")
 	flag.BoolVar(&cliops.version, "version", cliops.version, "print version")
 	flag.StringVar(&cliops.cachedir, "cache-dir", cliops.cachedir, "path to the directory with cached certificates (default: '')")
-	flag.IntVar(&cliops.cacheexpire, "cache-expire", cliops.cacheexpire, "duration of cached certificates (in seconds, default 3600)")
+	flag.IntVar(&cliops.cacheexpire, "cache-expire", cliops.cacheexpire, "duration of cached certificates (in seconds)")
 	flag.StringVar(&cliops.cafile, "ca-file", cliops.cafile, "file with root CA certificates in pem format")
 	flag.StringVar(&cliops.cainter, "ca-inter", cliops.cainter, "file with intermediate CA certificates in pem format")
 	flag.StringVar(&cliops.crlfile, "crl-file", cliops.crlfile, "file with CRL in pem format")
-	flag.IntVar(&cliops.certverify, "cert-verify", cliops.certverify, "certificate verification mode (default 0")
+	flag.IntVar(&cliops.certverify, "cert-verify", cliops.certverify, "certificate verification mode (default 0)")
+	flag.IntVar(&cliops.verbosity, "verbosity", cliops.verbosity, "verbosity level (default 0)")
+	flag.IntVar(&cliops.verbosity, "vl", cliops.verbosity, "verbosity level (default 0)")
 }
 
 func localTest() {
@@ -313,6 +317,9 @@ func secsipidxCLISign() int {
 	}
 
 	if useStruct {
+		if cliops.verbosity > 0 {
+			fmt.Printf("Signing using the structures build from parameter values\n")
+		}
 		prvkey, _ := ioutil.ReadFile(cliops.fprvkey)
 		var ecdsaPrvKey *ecdsa.PrivateKey
 
@@ -322,6 +329,9 @@ func secsipidxCLISign() int {
 		}
 		token = secsipid.SJWTEncode(header, payload, ecdsaPrvKey)
 	} else {
+		if cliops.verbosity > 0 {
+			fmt.Printf("Signing using the JSON documents from parameters\n")
+		}
 		token, _, _ = secsipid.SJWTEncodeText(sHeader, sPayload, cliops.fprvkey)
 	}
 	fmt.Printf("%s\n", token)
@@ -488,6 +498,9 @@ func main() {
 
 	ret = 0
 	if cliops.check {
+		if cliops.verbosity > 0 {
+			fmt.Printf("Running with check command\n")
+		}
 		ret = secsipidxCLICheck()
 		if ret == 0 {
 			fmt.Printf("ok\n")
@@ -496,9 +509,15 @@ func main() {
 		}
 		os.Exit(ret)
 	} else if cliops.signfull {
+		if cliops.verbosity > 0 {
+			fmt.Printf("Running with sign-full command\n")
+		}
 		ret = secsipidxCLISignFull()
 		os.Exit(ret)
 	} else if cliops.sign {
+		if cliops.verbosity > 0 {
+			fmt.Printf("Running with sign command\n")
+		}
 		ret = secsipidxCLISign()
 		os.Exit(ret)
 	} else {
